Index: bfd/cpu-m9s12xg.c |
diff --git a/bfd/cpu-d30v.c b/bfd/cpu-m9s12xg.c |
similarity index 72% |
copy from bfd/cpu-d30v.c |
copy to bfd/cpu-m9s12xg.c |
index d528e9bf67bac34cbb9f4910cd7bdc228766577e..6958a13ccb2382d6727a20901e8508f80e560d1c 100644 |
--- a/bfd/cpu-d30v.c |
+++ b/bfd/cpu-m9s12xg.c |
@@ -1,6 +1,5 @@ |
-/* BFD support for the Mitsubishi D30V processor |
- Copyright 1997, 2002, 2005, 2007 Free Software Foundation, Inc. |
- Contributed by Martin Hunt (hunt@cygnus.com). |
+/* BFD support for the Freescale 9S12-XGATE co-processor |
+ Copyright 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc. |
This file is part of BFD, the Binary File Descriptor library. |
@@ -23,18 +22,20 @@ |
#include "bfd.h" |
#include "libbfd.h" |
-const bfd_arch_info_type bfd_d30v_arch = |
+const bfd_arch_info_type bfd_m9s12xg_arch = |
{ |
- 32, /* Bits in a word. */ |
- 32, /* Bits in an address. */ |
- 8, /* Bits in a byte. */ |
- bfd_arch_d30v, |
+ 16, /* 16 bits in a word. */ |
+ 32, /* 16 bits in an address. */ |
+ 8, /* 8 bits in a byte. */ |
+ bfd_arch_m9s12xg, |
0, |
- "d30v", |
- "d30v", |
+ "m9s12xg", |
+ "m9s12xg", |
4, /* Section alignment power. */ |
TRUE, |
bfd_default_compatible, |
bfd_default_scan, |
+ bfd_arch_default_fill, |
0, |
}; |
+ |